from django.test import SimpleTestCase

from wagtailgeowidget.helpers import geosgeometry_str_to_struct


class GeosGeometryPrserHelperTestCase(SimpleTestCase):
    def test_that_basic_parsing_works(self):
        struct = geosgeometry_str_to_struct("SRID=5432;POINT(12.0 13.0)")

        self.assertEqual(struct["srid"], "5432")
        self.assertEqual(struct["x"], "12.0")
        self.assertEqual(struct["y"], "13.0")

    def test_none_is_returned_on_invalid_struct(self):
        struct = geosgeometry_str_to_struct("S=5432_P(12.0 13.0)")

        self.assertEqual(struct, None)

    def test_that_optional_space_between_point_and_data_is_accepted(self):
        struct = geosgeometry_str_to_struct("SRID=5432;POINT (12.0 13.0)")

        self.assertEqual(struct["srid"], "5432")
        self.assertEqual(struct["x"], "12.0")
        self.assertEqual(struct["y"], "13.0")



#!/usr/bin/env python

"""
wagtailgeowidget
----------
Wagtail-Geo-Widget is the complete map solution for your Wagtail site.
"""

__title__ = "wagtailgeowidget"
__version__ = "5.2.0"
__build__ = 520
__author__ = "Martin Sandström"
__license__ = "MIT"
__copyright__ = "Copyright 2015-2021 Fröjd Interactive"



from wagtail.admin.edit_handlers import FieldPanel

from wagtailgeowidget.app_settings import GEO_WIDGET_ZOOM
from wagtailgeowidget.widgets import GeoField


class GeoPanel(FieldPanel):
    def __init__(self, *args, **kwargs):
        self.classname = kwargs.pop("classname", "")
        self.address_field = kwargs.pop("address_field", "")
        self.hide_latlng = kwargs.pop("hide_latlng", False)
        self.zoom = kwargs.pop("zoom", GEO_WIDGET_ZOOM)

        super().__init__(*args, **kwargs)

    def widget_overrides(self):
        field = self.model._meta.get_field(self.field_name)
        srid = getattr(field, "srid", 4326)

        return {
            self.field_name: GeoField(
                address_field=self.address_field,
                hide_latlng=self.hide_latlng,
                zoom=self.zoom,
                srid=srid,
                id_prefix="id_",
                used_in="GeoPanel",
            )
        }

    def clone(self):
        return self.__class__(
            field_name=self.field_name,
            classname=self.classname,
            address_field=self.address_field,
            hide_latlng=self.hide_latlng,
            zoom=self.zoom,
        )



from django.conf import settings

GEO_WIDGET_DEFAULT_LOCATION = getattr(
    settings, "GEO_WIDGET_DEFAULT_LOCATION", {"lat": 59.3293, "lng": 18.0686}
)
GEO_WIDGET_EMPTY_LOCATION = getattr(settings, "GEO_WIDGET_EMPTY_LOCATION", False)
GEO_WIDGET_ZOOM = getattr(settings, "GEO_WIDGET_ZOOM", 7)
GOOGLE_MAPS_V3_APIKEY = getattr(settings, "GOOGLE_MAPS_V3_APIKEY", None)
GOOGLE_MAPS_V3_LANGUAGE = getattr(settings, "GOOGLE_MAPS_V3_LANGUAGE", "en")



#!/usr/bin/env python

import io
import os
import re
import sys
from pathlib import Path

from setuptools import find_packages, setup

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

version = ""
with io.open("wagtailgeowidget/__init__.py", "r", encoding="utf8") as fd:
    version = re.search(
        r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', fd.read(), re.MULTILINE
    ).group(1)

setup(
    name="wagtailgeowidget",
    version=version,
    description=(
        "Wagtail-Geo-Widget is the complete map solution for your Wagtail site."
    ),  # NOQA
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Fröjd",
    author_email="martin@marteinn.se",
    url="https://github.com/frojd/wagtail-geo-widget",
    packages=find_packages(exclude=("tests*", "tests", "example")),
    include_package_data=True,
    install_requires=[
        "Django>=2.2",
    ],
    license="MIT",
    zip_safe=False,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Framework :: Django",
        "Framework :: Django :: 2.2",
        "Framework :: Django :: 3.2",
        "Framework :: Django :: 4.0",
        "Topic :: Utilities",
        "Framework :: Wagtail",
        "Framework :: Wagtail :: 2",
    ],
)
